@@ -7,7 +7,7 @@ class editor():
         self.password = password
         self.host = host
         self.port = port
-        self.con = psycopg2.connect(db, user, password, host, port)
+        self.con = psycopg2.connect(database = db, user = user, password = password, host = host, port = port)
 
     def create_table(self, tablename, **kwargs):
         cur = self.con.cursor()
